@@ -259,18 +259,18 @@ static void
 file_notifier_traverse_tree (TrackerFileNotifier *notifier)
 {
 	TrackerFileNotifierPrivate *priv;
-	GFile *current_root, *canonical;
+	GFile *current_root, *config_root;
 	TrackerDirectoryFlags flags;
 
 	priv = notifier->priv;
 	current_root = priv->pending_index_roots->data;
-	tracker_indexing_tree_get_root (priv->indexing_tree,
-	                                current_root, &flags);
+	config_root = tracker_indexing_tree_get_root (priv->indexing_tree,
+						      current_root, &flags);
 
 	/* Check mtime for 1) directories with the check_mtime flag
 	 * and 2) directories gotten from monitor events.
 	 */
-	if (canonical != current_root ||
+	if (config_root != current_root ||
 	    flags & TRACKER_DIRECTORY_FLAG_CHECK_MTIME) {
 		tracker_file_system_traverse (priv->file_system,
 		                              current_root,
@@ -284,7 +284,7 @@ file_notifier_traverse_tree (TrackerFileNotifier *notifier)
 	                                  current_root,
 	                                  G_FILE_TYPE_REGULAR);
 
-	tracker_info ("Finished notifying files after %2.2f seconds",
+	tracker_info ("  Notified files after %2.2f seconds",
 	              g_timer_elapsed (priv->timer, NULL));
 
 	/* We've finished crawling/querying on the first element
@@ -374,12 +374,12 @@ crawler_directory_crawled_cb (TrackerCrawler *crawler,
 	               directories_found, directories_ignored,
 	               files_found, files_ignored);
 
-	g_message ("  Found %d directories, ignored %d directories",
-	           directories_found,
-	           directories_ignored);
-	g_message ("  Found %d files, ignored %d files",
-	           files_found,
-	           files_ignored);
+	tracker_info ("  Found %d directories, ignored %d directories",
+	              directories_found,
+	              directories_ignored);
+	tracker_info ("  Found %d files, ignored %d files",
+	              files_found,
+	              files_ignored);
 }
 
 static void
@@ -472,7 +472,7 @@ sparql_query_cb (GObject      *object,
 	                                  quark_property_queried,
 	                                  GUINT_TO_POINTER (TRUE));
 
-	tracker_info ("finished querying files after %2.2f seconds",
+	tracker_info ("  Queried files after %2.2f seconds",
 	              g_timer_elapsed (priv->timer, NULL));
 
 	/* If it's also been crawled, finish operation */
@@ -631,7 +631,7 @@ crawler_finished_cb (TrackerCrawler *crawler,
 	TrackerFileNotifier *notifier = user_data;
 	TrackerFileNotifierPrivate *priv = notifier->priv;
 
-	tracker_info ("%s crawling files after %2.2f seconds",
+	tracker_info ("  %s crawling files after %2.2f seconds",
 	              was_interrupted ? "Stopped" : "Finished",
 	              g_timer_elapsed (priv->timer, NULL));
 
@@ -1020,7 +1020,15 @@ indexing_tree_directory_removed (TrackerIndexingTree *indexing_tree,
 	TrackerDirectoryFlags flags;
 
 	/* Flags are still valid at the moment of deletion */
-	directory = tracker_indexing_tree_get_root (indexing_tree, directory, &flags);
+	tracker_indexing_tree_get_root (indexing_tree, directory, &flags);
+	directory = tracker_file_system_peek_file (priv->file_system, directory);
+
+	if (!directory) {
+		/* If the dir has no canonical copy,
+		 * it wasn't even told to be indexed.
+		 */
+		return;
+	}
 
 	/* If the folder was being ignored, index/crawl it from scratch */
 	if (flags & TRACKER_DIRECTORY_FLAG_IGNORE) {
