@@ -340,7 +340,10 @@ test_common_context_expect_results (TestCommonContext   *fixture,
 		}
 
 		g_main_loop_run (fixture->main_loop);
-		g_source_remove (id);
+
+		if (max_timeout != 0) {
+			g_source_remove (id);
+		}
 	}
 
 	for (i = 0; i < n_results; i++) {
@@ -408,7 +411,7 @@ test_file_notifier_crawling_non_recursive (TestCommonContext *fixture,
 	CREATE_UPDATE_FILE (fixture, "non-recursive/bbb");
 
 	test_common_context_index_dir (fixture, "non-recursive",
-	                               TRACKER_DIRECTORY_FLAG_NONE);
+	                               TRACKER_DIRECTORY_FLAG_CHECK_MTIME);
 
 	tracker_file_notifier_start (fixture->notifier);
 
@@ -435,7 +438,8 @@ test_file_notifier_crawling_recursive (TestCommonContext *fixture,
 	CREATE_UPDATE_FILE (fixture, "recursive/bbb");
 
 	test_common_context_index_dir (fixture, "recursive",
-	                               TRACKER_DIRECTORY_FLAG_RECURSE);
+	                               TRACKER_DIRECTORY_FLAG_RECURSE |
+	                               TRACKER_DIRECTORY_FLAG_CHECK_MTIME);
 
 	tracker_file_notifier_start (fixture->notifier);
 
@@ -469,9 +473,11 @@ test_file_notifier_crawling_non_recursive_within_recursive (TestCommonContext *f
 	CREATE_UPDATE_FILE (fixture, "recursive/folder/non-recursive/folder/ddd");
 
 	test_common_context_index_dir (fixture, "recursive",
-	                               TRACKER_DIRECTORY_FLAG_RECURSE);
+	                               TRACKER_DIRECTORY_FLAG_RECURSE |
+	                               TRACKER_DIRECTORY_FLAG_CHECK_MTIME);
 	test_common_context_index_dir (fixture, "recursive/folder/non-recursive",
-	                               TRACKER_DIRECTORY_FLAG_NONE);
+	                               TRACKER_DIRECTORY_FLAG_NONE |
+	                               TRACKER_DIRECTORY_FLAG_CHECK_MTIME);
 
 	tracker_file_notifier_start (fixture->notifier);
 
@@ -505,9 +511,11 @@ test_file_notifier_crawling_recursive_within_non_recursive (TestCommonContext *f
 	CREATE_UPDATE_FILE (fixture, "non-recursive/folder/recursive/folder/ddd");
 
 	test_common_context_index_dir (fixture, "non-recursive/folder/recursive",
-	                               TRACKER_DIRECTORY_FLAG_RECURSE);
+	                               TRACKER_DIRECTORY_FLAG_RECURSE |
+	                               TRACKER_DIRECTORY_FLAG_CHECK_MTIME);
 	test_common_context_index_dir (fixture, "non-recursive",
-	                               TRACKER_DIRECTORY_FLAG_NONE);
+	                               TRACKER_DIRECTORY_FLAG_NONE |
+	                               TRACKER_DIRECTORY_FLAG_CHECK_MTIME);
 
 	tracker_file_notifier_start (fixture->notifier);
 
@@ -539,9 +547,11 @@ test_file_notifier_crawling_ignore_within_recursive (TestCommonContext *fixture,
 	CREATE_UPDATE_FILE (fixture, "recursive/folder/ignore/folder/ddd");
 
 	test_common_context_index_dir (fixture, "recursive",
-	                               TRACKER_DIRECTORY_FLAG_RECURSE);
+	                               TRACKER_DIRECTORY_FLAG_RECURSE |
+	                               TRACKER_DIRECTORY_FLAG_CHECK_MTIME);
 	test_common_context_index_dir (fixture, "recursive/folder/ignore",
-	                               TRACKER_DIRECTORY_FLAG_IGNORE);
+	                               TRACKER_DIRECTORY_FLAG_IGNORE |
+	                               TRACKER_DIRECTORY_FLAG_CHECK_MTIME);
 
 	tracker_file_notifier_start (fixture->notifier);
 
@@ -646,7 +656,8 @@ test_file_notifier_monitor_updates_non_recursive (TestCommonContext *fixture,
 	CREATE_UPDATE_FILE (fixture, "non-recursive/bbb");
 
 	test_common_context_index_dir (fixture, "non-recursive",
-	                               TRACKER_DIRECTORY_FLAG_MONITOR);
+	                               TRACKER_DIRECTORY_FLAG_MONITOR |
+	                               TRACKER_DIRECTORY_FLAG_CHECK_MTIME);
 
 	tracker_file_notifier_start (fixture->notifier);
 	test_common_context_expect_results (fixture, expected_results,
@@ -693,7 +704,8 @@ test_file_notifier_monitor_updates_recursive (TestCommonContext *fixture,
 
 	test_common_context_index_dir (fixture, "recursive",
 	                               TRACKER_DIRECTORY_FLAG_RECURSE |
-	                               TRACKER_DIRECTORY_FLAG_MONITOR);
+	                               TRACKER_DIRECTORY_FLAG_MONITOR |
+	                               TRACKER_DIRECTORY_FLAG_CHECK_MTIME);
 
 	tracker_file_notifier_start (fixture->notifier);
 	test_common_context_expect_results (fixture, expected_results,
